@@ -247,7 +247,7 @@ TEST_CASE_METHOD(
   SubarrayRanges<uint64_t> ranges = {{5, 15}};
   Layout subarray_layout = Layout::ROW_MAJOR;
   create_subarray(array_->array_, ranges, subarray_layout, &subarray);
-  CHECK(subarray.compute_tile_coords<uint64_t>().ok());
+  CHECK_NOTHROW(subarray.compute_tile_coords<uint64_t>());
 
   // Create result space tiles
   std::vector<uint64_t> slice = {1, 100};
@@ -262,7 +262,7 @@ TEST_CASE_METHOD(
       HERE(),
       nullptr,
       array_->array_->array_schema_latest_ptr(),
-      URI(),
+      generate_fragment_uri(array_->array_.get()),
       std::make_pair<uint64_t, uint64_t>(0, 0),
       tiledb::test::create_test_memory_tracker(),
       true);
@@ -321,7 +321,7 @@ TEST_CASE_METHOD(
   SubarrayRanges<uint64_t> ranges = {{5, 15}};
   Layout subarray_layout = Layout::ROW_MAJOR;
   create_subarray(array_->array_, ranges, subarray_layout, &subarray);
-  CHECK(subarray.compute_tile_coords<uint64_t>().ok());
+  CHECK_NOTHROW(subarray.compute_tile_coords<uint64_t>());
 
   // Create result space tiles
   std::vector<uint64_t> slice = {20, 30};
@@ -336,7 +336,7 @@ TEST_CASE_METHOD(
       HERE(),
       nullptr,
       array_->array_->array_schema_latest_ptr(),
-      URI(),
+      generate_fragment_uri(array_->array_.get()),
       std::make_pair<uint64_t, uint64_t>(0, 0),
       tiledb::test::create_test_memory_tracker(),
       true);
@@ -395,7 +395,7 @@ TEST_CASE_METHOD(
   SubarrayRanges<uint64_t> ranges = {{5, 15, 3, 5, 11, 14}};
   Layout subarray_layout = Layout::ROW_MAJOR;
   create_subarray(array_->array_, ranges, subarray_layout, &subarray);
-  CHECK(subarray.compute_tile_coords<uint64_t>().ok());
+  CHECK_NOTHROW(subarray.compute_tile_coords<uint64_t>());
 
   // Create result space tiles
   std::vector<uint64_t> slice_1 = {5, 12};
@@ -414,7 +414,7 @@ TEST_CASE_METHOD(
         HERE(),
         nullptr,
         array_->array_->array_schema_latest_ptr(),
-        URI(),
+        generate_fragment_uri(array_->array_.get()),
         std::make_pair<uint64_t, uint64_t>(0, 0),
         tiledb::test::create_test_memory_tracker(),
         true);
@@ -480,7 +480,7 @@ TEST_CASE_METHOD(
   SubarrayRanges<uint64_t> ranges = {{3, 15, 18, 20}};
   Layout subarray_layout = Layout::ROW_MAJOR;
   create_subarray(array_->array_, ranges, subarray_layout, &subarray);
-  CHECK(subarray.compute_tile_coords<uint64_t>().ok());
+  CHECK_NOTHROW(subarray.compute_tile_coords<uint64_t>());
 
   // Create result space tiles
   std::vector<uint64_t> slice = {3, 12};
@@ -497,7 +497,7 @@ TEST_CASE_METHOD(
         HERE(),
         nullptr,
         array_->array_->array_schema_latest_ptr(),
-        URI(),
+        generate_fragment_uri(array_->array_.get()),
         std::make_pair<uint64_t, uint64_t>(0, 0),
         tiledb::test::create_test_memory_tracker(),
         true);
@@ -704,7 +704,7 @@ TEST_CASE_METHOD(
   Subarray subarray;
   SubarrayRanges<uint64_t> ranges = {{2, 3}, {2, 6}};
   create_subarray(array_->array_, ranges, subarray_layout, &subarray);
-  CHECK(subarray.compute_tile_coords<uint64_t>().ok());
+  CHECK_NOTHROW(subarray.compute_tile_coords<uint64_t>());
 
   // Create result space tiles
   std::vector<uint64_t> slice = {1, 6, 1, 6};
@@ -720,7 +720,7 @@ TEST_CASE_METHOD(
       HERE(),
       nullptr,
       array_->array_->array_schema_latest_ptr(),
-      URI(),
+      generate_fragment_uri(array_->array_.get()),
       std::make_pair<uint64_t, uint64_t>(0, 0),
       tiledb::test::create_test_memory_tracker(),
       true);
@@ -890,7 +890,7 @@ TEST_CASE_METHOD(
   Subarray subarray;
   SubarrayRanges<uint64_t> ranges = {{2, 3}, {2, 6}};
   create_subarray(array_->array_, ranges, subarray_layout, &subarray);
-  CHECK(subarray.compute_tile_coords<uint64_t>().ok());
+  CHECK_NOTHROW(subarray.compute_tile_coords<uint64_t>());
 
   // Create result space tiles
   std::vector<uint64_t> slice = {6, 6, 6, 6};
@@ -906,7 +906,7 @@ TEST_CASE_METHOD(
       HERE(),
       nullptr,
       array_->array_->array_schema_latest_ptr(),
-      URI(),
+      generate_fragment_uri(array_->array_.get()),
       std::make_pair<uint64_t, uint64_t>(0, 0),
       tiledb::test::create_test_memory_tracker(),
       true);
@@ -1089,7 +1089,7 @@ TEST_CASE_METHOD(
   Subarray subarray;
   SubarrayRanges<uint64_t> ranges = {{2, 3}, {2, 6}};
   create_subarray(array_->array_, ranges, subarray_layout, &subarray);
-  CHECK(subarray.compute_tile_coords<uint64_t>().ok());
+  CHECK_NOTHROW(subarray.compute_tile_coords<uint64_t>());
 
   // Create result space tiles
   std::vector<uint64_t> slice = {3, 6, 5, 6};
@@ -1105,7 +1105,7 @@ TEST_CASE_METHOD(
       HERE(),
       nullptr,
       array_->array_->array_schema_latest_ptr(),
-      URI(),
+      generate_fragment_uri(array_->array_.get()),
       std::make_pair<uint64_t, uint64_t>(0, 0),
       tiledb::test::create_test_memory_tracker(),
       true);
@@ -1332,7 +1332,7 @@ TEST_CASE_METHOD(
   Subarray subarray;
   SubarrayRanges<uint64_t> ranges = {{3, 5}, {2, 4, 5, 6}};
   create_subarray(array_->array_, ranges, subarray_layout, &subarray);
-  CHECK(subarray.compute_tile_coords<uint64_t>().ok());
+  CHECK_NOTHROW(subarray.compute_tile_coords<uint64_t>());
 
   // Create result space tiles
   std::vector<uint64_t> slice_1 = {3, 5, 2, 4};
@@ -1351,7 +1351,7 @@ TEST_CASE_METHOD(
         HERE(),
         nullptr,
         array_->array_->array_schema_latest_ptr(),
-        URI(),
+        generate_fragment_uri(array_->array_.get()),
         std::make_pair<uint64_t, uint64_t>(0, 0),
         tiledb::test::create_test_memory_tracker(),
         true);
