@@ -889,6 +889,42 @@ TEST_CASE_METHOD(
       "DenseReader: Memory budget is too small to open array");
 }
 
+TEST_CASE_METHOD(
+    CDenseFx,
+    "Dense reader: budget too small for tile offsets",
+    "[dense-reader][budget-too-small-tile-offsets]") {
+  // Create default array.
+  reset_config();
+  create_default_array_1d();
+
+  uint64_t num_frags = GENERATE(1, 2);
+
+  // Write some fragments.
+  int subarray[] = {1, NUM_CELLS};
+  std::vector<int> data(NUM_CELLS);
+  std::iota(data.begin(), data.end(), 1);
+  uint64_t data_size = data.size() * sizeof(int);
+  for (uint64_t f = 0; f < num_frags; f++) {
+    write_1d_fragment(subarray, data.data(), &data_size);
+  }
+
+  // Footer for a fragment is 390 bytes.
+  // Tile offsets for a fragment are 400 bytes.
+  // Tile upper memory limit is more than enough to load 40 bytes tiles.
+  total_budget_ = std::to_string(390 * num_frags + 200);
+  update_config();
+
+  // Try to read.
+  int data_r[NUM_CELLS] = {0};
+  uint64_t data_r_size = sizeof(data_r);
+  read(
+      subarray,
+      data_r,
+      &data_r_size,
+      0,
+      "DenseReader: Cannot load tile offsets, increase memory budget");
+}
+
 TEST_CASE_METHOD(
     CDenseFx,
     "Dense reader: tile budget exceeded, fixed attribute",
@@ -942,7 +978,7 @@ TEST_CASE_METHOD(
   uint64_t data_size = data.size() * sizeof(int);
   write_1d_fragment(subarray, data.data(), &data_size);
 
-  total_budget_ = "420";
+  total_budget_ = "804";
   tile_upper_memory_limit_ = "50";
   update_config();
 
@@ -1025,7 +1061,7 @@ TEST_CASE_METHOD(
 
   // Each tiles are 91 and 100 bytes respectively, this will only allow to
   // load one as the budget is split across two potential reads.
-  total_budget_ = "460";
+  total_budget_ = "840";
   tile_upper_memory_limit_ = "210";
   update_config();
 
