@@ -31,6 +31,7 @@
  */
 
 #include "test/support/src/helpers.h"
+#include "test/support/src/vfs_helpers.h"
 #include "tiledb/sm/c_api/tiledb.h"
 #include "tiledb/sm/c_api/tiledb_struct_def.h"
 #include "tiledb/sm/cpp_api/tiledb"
@@ -364,8 +365,14 @@ int32_t CSparseGlobalOrderFx::read(
 
   if (set_subarray) {
     // Set subarray.
-    rc = tiledb_query_set_subarray(ctx_, query, subarray.data());
+    tiledb_subarray_t* sub;
+    rc = tiledb_subarray_alloc(ctx_, array, &sub);
     CHECK(rc == TILEDB_OK);
+    rc = tiledb_subarray_set_subarray(ctx_, sub, subarray.data());
+    CHECK(rc == TILEDB_OK);
+    rc = tiledb_query_set_subarray_t(ctx_, query, sub);
+    CHECK(rc == TILEDB_OK);
+    tiledb_subarray_free(&sub);
   }
 
   if (qc_idx != 0) {
@@ -447,8 +454,14 @@ int32_t CSparseGlobalOrderFx::read_strings(
 
   if (set_subarray) {
     // Set subarray.
-    rc = tiledb_query_set_subarray(ctx_, query, subarray.data());
+    tiledb_subarray_t* sub;
+    rc = tiledb_subarray_alloc(ctx_, array, &sub);
     CHECK(rc == TILEDB_OK);
+    rc = tiledb_subarray_set_subarray(ctx_, sub, subarray.data());
+    CHECK(rc == TILEDB_OK);
+    rc = tiledb_query_set_subarray_t(ctx_, query, sub);
+    CHECK(rc == TILEDB_OK);
+    tiledb_subarray_free(&sub);
   }
 
   rc = tiledb_query_set_layout(ctx_, query, TILEDB_GLOBAL_ORDER);
@@ -775,10 +788,10 @@ TEST_CASE_METHOD(
     write_1d_fragment(coords, &coords_size, data, &data_size);
   }
 
-  // Two result tile (2 * (~1200 + 8) will be bigger than the per fragment
+  // Two result tile (2 * (~3000 + 8) will be bigger than the per fragment
   // budget (1000).
-  total_budget_ = "12000";
-  ratio_coords_ = "0.30";
+  total_budget_ = "35000";
+  ratio_coords_ = "0.11";
   update_config();
 
   tiledb_array_t* array = nullptr;
@@ -857,7 +870,7 @@ TEST_CASE_METHOD(
   write_1d_fragment(coords, &coords_size, data, &data_size);
 
   // One result tile (8 + ~440) will be bigger than the budget (400).
-  total_budget_ = "10000";
+  total_budget_ = "19000";
   ratio_coords_ = "0.04";
   update_config();
 
@@ -1122,22 +1135,10 @@ TEST_CASE_METHOD(
 
 TEST_CASE(
     "Sparse global order reader: user buffer cannot fit single cell",
-    "[sparse-global-order][user-buffer][too-small]") {
-  bool serialized = false, refactored_query_v2 = false;
-#ifdef TILEDB_SERIALIZATION
-  serialized = GENERATE(true, false);
-  if (serialized) {
-    refactored_query_v2 = GENERATE(true, false);
-  }
-#endif
-
-  std::string array_name = "test_sparse_global_order";
-  Context ctx;
-  VFS vfs(ctx);
-
-  if (vfs.is_dir(array_name)) {
-    vfs.remove_dir(array_name);
-  }
+    "[sparse-global-order][user-buffer][too-small][rest]") {
+  VFSTestSetup vfs_test_setup;
+  std::string array_name = vfs_test_setup.array_uri("test_sparse_global_order");
+  auto ctx = vfs_test_setup.ctx();
 
   // Create array with var-sized attribute.
   Domain dom(ctx);
@@ -1171,15 +1172,7 @@ TEST_CASE(
   query.set_offsets_buffer("a", a1_offsets);
 
   // Submit query
-  ServerQueryBuffers server_buffers_;
-  auto rc = submit_query_wrapper(
-      ctx,
-      array_name,
-      &query,
-      server_buffers_,
-      serialized,
-      refactored_query_v2);
-  REQUIRE(rc == TILEDB_OK);
+  query.submit_and_finalize();
 
   // Read using a buffer that can't fit a single result
   Array array2(ctx, array_name, TILEDB_READ);
@@ -1198,48 +1191,26 @@ TEST_CASE(
 
   // The user buffer cannot fit a single result so it should return Incomplete
   // with the right reason
-  rc = submit_query_wrapper(
-      ctx,
-      array_name,
-      &query2,
-      server_buffers_,
-      serialized,
-      refactored_query_v2,
-      false);
-  REQUIRE(rc == TILEDB_OK);
+  query2.submit();
   REQUIRE(query2.query_status() == Query::Status::INCOMPLETE);
 
-  // For remote arrays the reason is always TILEDB_REASON_USER_BUFFER_SIZE,
-  // but we can't test it here since we simulate "remote" arrays by using a
-  // local URI so the array->is_remote() check will fail, and we won't get the
-  // correct result.
-  if (!serialized) {
-    tiledb_query_status_details_t details;
-    rc = tiledb_query_get_status_details(
-        ctx.ptr().get(), query2.ptr().get(), &details);
-    CHECK(rc == TILEDB_OK);
-    CHECK(details.incomplete_reason == TILEDB_REASON_USER_BUFFER_SIZE);
-  }
+  tiledb_query_status_details_t details;
+  auto rc = tiledb_query_get_status_details(
+      ctx.ptr().get(), query2.ptr().get(), &details);
+  CHECK(rc == TILEDB_OK);
+  CHECK(details.incomplete_reason == TILEDB_REASON_USER_BUFFER_SIZE);
 
   array2.close();
-
-  if (vfs.is_dir(array_name)) {
-    vfs.remove_dir(array_name);
-  }
 }
 
 TEST_CASE(
     "Sparse global order reader: attribute copy memory limit",
-    "[sparse-global-order][attribute-copy][memory-limit]") {
-  std::string array_name = "test_sparse_global_order";
+    "[sparse-global-order][attribute-copy][memory-limit][rest]") {
   Config config;
-  config["sm.mem.total_budget"] = "10000";
-  Context ctx(config);
-  VFS vfs(ctx);
-
-  if (vfs.is_dir(array_name)) {
-    vfs.remove_dir(array_name);
-  }
+  config["sm.mem.total_budget"] = "20000";
+  VFSTestSetup vfs_test_setup(config.ptr().get());
+  std::string array_name = vfs_test_setup.array_uri("test_sparse_global_order");
+  auto ctx = vfs_test_setup.ctx();
 
   // Create array with var-sized attribute.
   Domain dom(ctx);
@@ -1274,8 +1245,7 @@ TEST_CASE(
   query.set_data_buffer("d1", d1);
   query.set_data_buffer("a", a1_data);
   query.set_offsets_buffer("a", a1_offsets);
-  CHECK_NOTHROW(query.submit());
-  CHECK_NOTHROW(query.finalize());
+  CHECK_NOTHROW(query.submit_and_finalize());
 
   // Read using a budget that can only fit one of the var size tiles.
   Array array2(ctx, array_name, TILEDB_READ);
@@ -1304,10 +1274,6 @@ TEST_CASE(
   CHECK(result_num == 4);
 
   array2.close();
-
-  if (vfs.is_dir(array_name)) {
-    vfs.remove_dir(array_name);
-  }
 }
 
 TEST_CASE_METHOD(
@@ -1346,10 +1312,10 @@ TEST_CASE_METHOD(
     write_1d_fragment(coords, &coords_size, data, &data_size);
   }
 
-  // Two result tile (2 * (~1200 + 8) will be bigger than the per fragment
+  // Two result tile (2 * (~4000 + 8) will be bigger than the per fragment
   // budget (1000).
-  total_budget_ = "12000";
-  ratio_coords_ = "0.30";
+  total_budget_ = "40000";
+  ratio_coords_ = "0.22";
   update_config();
 
   tiledb_array_t* array = nullptr;
