@@ -52,11 +52,8 @@ namespace tiledb::sm {
 
 class ArraySchema;
 class ArraySchemaEvolution;
-class SchemaEvolution;
 class FragmentMetadata;
 class MemoryTracker;
-class UpdateValue;
-class QueryCondition;
 enum class QueryType : uint8_t;
 
 /**
@@ -215,17 +212,6 @@ class OpenedArray {
     return is_remote_;
   }
 
-  /**
-   * Loads the delete and update conditions from storage.
-   *
-   * @return Status, vector of the conditions, vector of the update values.
-   */
-  tuple<
-      Status,
-      optional<std::vector<QueryCondition>>,
-      optional<std::vector<std::vector<UpdateValue>>>>
-  load_delete_and_update_conditions();
-
  private:
   /** The context resources. */
   ContextResources& resources_;
