@@ -275,7 +275,10 @@ int32_t tiledb_filestore_uri_import(
       get_buffer_size_from_config(context.resources().config(), tile_extent);
 
   tiledb::sm::Query query(
-      context.resources(), context.storage_manager(), array);
+      context.resources(),
+      context.cancellation_source(),
+      context.storage_manager(),
+      array);
   throw_if_not_ok(query.set_layout(tiledb::sm::Layout::GLOBAL_ORDER));
   std::vector<std::byte> buffer(buffer_size);
 
@@ -298,7 +301,10 @@ int32_t tiledb_filestore_uri_import(
 
   auto tiledb_cloud_fix = [&](uint64_t start, uint64_t end) {
     tiledb::sm::Query query(
-        context.resources(), context.storage_manager(), array);
+        context.resources(),
+        context.cancellation_source(),
+        context.storage_manager(),
+        array);
     throw_if_not_ok(query.set_layout(tiledb::sm::Layout::ROW_MAJOR));
     tiledb::sm::Subarray subarray_cloud_fix(
         array.get(), nullptr, context.resources().logger(), true);
@@ -432,7 +438,10 @@ int32_t tiledb_filestore_uri_export(
     subarray.add_range(0, std::move(subarray_range));
 
     tiledb::sm::Query query(
-        context.resources(), context.storage_manager(), array);
+        context.resources(),
+        context.cancellation_source(),
+        context.storage_manager(),
+        array);
     throw_if_not_ok(query.set_layout(tiledb::sm::Layout::ROW_MAJOR));
     query.set_subarray(subarray);
 
@@ -536,7 +545,10 @@ int32_t tiledb_filestore_buffer_import(
       "");
 
   tiledb::sm::Query query(
-      context.resources(), context.storage_manager(), array);
+      context.resources(),
+      context.cancellation_source(),
+      context.storage_manager(),
+      array);
   throw_if_not_ok(query.set_layout(tiledb::sm::Layout::ROW_MAJOR));
 
   tiledb::sm::Subarray subarray(
@@ -606,7 +618,10 @@ int32_t tiledb_filestore_buffer_export(
   subarray.add_range(0, std::move(subarray_range));
 
   tiledb::sm::Query query(
-      context.resources(), context.storage_manager(), array);
+      context.resources(),
+      context.cancellation_source(),
+      context.storage_manager(),
+      array);
   throw_if_not_ok(query.set_layout(tiledb::sm::Layout::ROW_MAJOR));
   query.set_subarray(subarray);
   uint64_t size_tmp = size;
