@@ -45,7 +45,6 @@
 #include <string>
 #include <vector>
 
-#include "tiledb/common/logger.h"
 #include "tiledb/common/status.h"
 #include "tiledb/sm/config/config.h"
 #include "tiledb/sm/filesystem/filesystem_base.h"
@@ -261,8 +260,8 @@ class Posix : public FilesystemBase {
    * @param uri The parent path to list sub-paths.
    * @return A list of directory_entry objects
    */
-  tuple<Status, optional<std::vector<filesystem::directory_entry>>>
-  ls_with_sizes(const URI& uri) const override;
+  std::vector<filesystem::directory_entry> ls_with_sizes(
+      const URI& uri) const override;
 
   /**
    * Lists objects and object information that start with `prefix`, invoking
