@@ -5,7 +5,7 @@
  *
  * The MIT License
  *
- * @copyright Copyright (c) 2022 TileDB, Inc.
+ * @copyright Copyright (c) 2022-2024 TileDB, Inc.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -38,21 +38,6 @@
 
 namespace tiledb::sm::utils::parse {
 
-/**
- * Retrieves the timestamp range from the input
- * URI. For format version <= 2, only the range start is valid
- * (the range end is ignored).
- */
-Status get_timestamp_range(
-    const URI& uri, std::pair<uint64_t, uint64_t>* timestamp_range);
-
-/**
- * Retrieves the fragment version. This will work only for
- * name versions > 2, otherwise the function sets `version`
- * to UINT32_MAX.
- */
-format_version_t get_fragment_version(const std::string& name);
-
 /**
  * Returns true if the given URIs have the same "prefix" and could
  * potentially intersect one another.
